voice_audio_visualizer library

A comprehensive Flutter audio package with recording, playback, editing, and waveform visualization for all platforms.

Classes

AudioEditorController
Controller for audio editing operations
AudioEditorWidget
Customizable widget for editing audio with waveform visualization
AudioFile
Represents an audio file with metadata
AudioPlayerController
Controller for audio playback with waveform visualization
AudioPlayerWidget
Customizable widget for playing audio with waveform visualization
AudioRecorderController
Controller for audio recording with waveform generation
AudioRecorderWidget
Customizable widget for recording audio with live waveform visualization
AudioUtils
Utility functions for audio operations
AudioVisualizerTheme
Theme data for all audio visualizer widgets
AudioWaveform
Widget to display audio waveform visualization
CompactVoiceMessage
Compact voice message for lists
EditHistory
Represents a list of edit operations
EditOperation
Represents a single edit operation
EditorTheme
Theme for editor widget
EditRegion
Represents a region in the audio for editing
PlayerTheme
Theme for player widget
RecorderConfig
Configuration for audio recording
RecorderTheme
Theme for recorder widget
VoiceBubbleStyle
Voice bubble style configuration
VoiceMessageBubble
Customizable chat-style voice message bubble widget
WaveformData
Represents waveform data for visualization
WaveformExtractor
Extracts waveform data from audio
WaveformStyle
Waveform style configuration

Enums

AudioEncoder
Audio encoder types
EditAction
Actions that can be performed on a region
EditorState
State of the audio editor
FinishMode
Finish mode for player
PlayerState
State of the audio player
RecorderState
State of the audio recorder
WaveformType
Types of waveform visualization